@@ -221,22 +221,23 @@ library(xts)
 
 
 ###################################################
-### code chunk number 21: jss816.Rnw:932-935
+### code chunk number 21: jss816.Rnw:932-936
 ###################################################
 library(maptools)
 fname = system.file("shapes/sids.shp", package="maptools")[1]
-nc = readShapePoly(fname, proj4string=CRS("+proj=longlat +datum=NAD27"))
+nc = readShapePoly(fname, 
+	proj4string = CRS("+proj=longlat +datum=NAD27 +ellps=clrk66"))
 
 
 ###################################################
-### code chunk number 22: jss816.Rnw:938-940
+### code chunk number 22: jss816.Rnw:939-941
 ###################################################
 time = as.POSIXct(c("1974-07-01", "1979-07-01"), tz = "GMT")
 endTime = as.POSIXct(c("1978-06-30", "1984-06-30"), tz = "GMT")
 
 
 ###################################################
-### code chunk number 23: jss816.Rnw:943-947
+### code chunk number 23: jss816.Rnw:944-948
 ###################################################
 data = data.frame(
 	BIR = c(nc$BIR74, nc$BIR79),
@@ -245,13 +246,13 @@ data = data.frame(
 
 
 ###################################################
-### code chunk number 24: jss816.Rnw:950-951
+### code chunk number 24: jss816.Rnw:951-952
 ###################################################
 nct = STFDF(sp = as(nc, "SpatialPolygons"), time, data, endTime)
 
 
 ###################################################
-### code chunk number 25: jss816.Rnw:960-965
+### code chunk number 25: jss816.Rnw:961-966
 ###################################################
 library(maps)
 states.m = map('state', plot=FALSE, fill=TRUE)
@@ -261,42 +262,42 @@ states = map2SpatialPolygons(states.m, IDs=IDs)
 
 
 ###################################################
-### code chunk number 26: jss816.Rnw:968-970
+### code chunk number 26: jss816.Rnw:969-971
 ###################################################
 yrs = 1970:1986
 time = as.POSIXct(paste(yrs, "-01-01", sep=""), tz = "GMT")
 
 
 ###################################################
-### code chunk number 27: jss816.Rnw:973-975
+### code chunk number 27: jss816.Rnw:974-976
 ###################################################
 library(plm)
 data("Produc")
 
 
 ###################################################
-### code chunk number 28: jss816.Rnw:981-983
+### code chunk number 28: jss816.Rnw:982-984
 ###################################################
 # deselect District of Columbia, polygon 8, which is not present in Produc:
 Produc.st = STFDF(states[-8], time, Produc[order(Produc[2], Produc[1]),])
 
 
 ###################################################
-### code chunk number 29: jss816.Rnw:985-987
+### code chunk number 29: jss816.Rnw:986-988
 ###################################################
 library(RColorBrewer)
 stplot(Produc.st[,,"unemp"], yrs, col.regions = brewer.pal(9, "YlOrRd"),cuts=9)
 
 
 ###################################################
-### code chunk number 30: jss816.Rnw:1010-1012
+### code chunk number 30: jss816.Rnw:1011-1013
 ###################################################
 zz <- plm(log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, 
 	data = as.data.frame(Produc.st), index = c("state", "year"))
 
 
 ###################################################
-### code chunk number 31: jss816.Rnw:1033-1039
+### code chunk number 31: jss816.Rnw:1034-1040
 ###################################################
 library(gstat)
 data("wind")
@@ -307,7 +308,7 @@ proj4string(wind.loc) = "+proj=longlat +datum=WGS84"
 
 
 ###################################################
-### code chunk number 32: jss816.Rnw:1044-1049
+### code chunk number 32: jss816.Rnw:1045-1050
 ###################################################
 library(mapdata)
 plot(wind.loc, xlim = c(-11,-5.4), ylim = c(51,55.5), axes=T, col="red",
@@ -317,20 +318,20 @@ text(coordinates(wind.loc), pos=1, label=wind.loc$Station, cex=.7)
 
 
 ###################################################
-### code chunk number 33: jss816.Rnw:1061-1062
+### code chunk number 33: jss816.Rnw:1062-1063
 ###################################################
 wind[1:3,]
 
 
 ###################################################
-### code chunk number 34: jss816.Rnw:1066-1068
+### code chunk number 34: jss816.Rnw:1067-1069
 ###################################################
 wind$time = ISOdate(wind$year+1900, wind$month, wind$day)
 wind$jday = as.numeric(format(wind$time, '%j'))
 
 
 ###################################################
-### code chunk number 35: jss816.Rnw:1073-1080
+### code chunk number 35: jss816.Rnw:1074-1081
 ###################################################
 stations = 4:15
 windsqrt = sqrt(0.5148 * as.matrix(wind[stations])) # knots -> m/s
@@ -342,24 +343,24 @@ velocities = apply(windsqrt, 2, function(x) { x - meanwind })
 
 
 ###################################################
-### code chunk number 36: jss816.Rnw:1085-1089
+### code chunk number 36: jss816.Rnw:1086-1090
 ###################################################
 wind.loc = wind.loc[match(names(wind[4:15]), wind.loc$Code),]
 pts = coordinates(wind.loc[match(names(wind[4:15]), wind.loc$Code),])
 rownames(pts) = wind.loc$Station
-pts = SpatialPoints(pts, CRS("+proj=longlat +datum=WGS84"))
+pts = SpatialPoints(pts, CRS("+proj=longlat +datum=WGS84 +ellps=WGS84"))
 
 
 ###################################################
-### code chunk number 37: jss816.Rnw:1095-1098
+### code chunk number 37: jss816.Rnw:1096-1099
 ###################################################
 library(rgdal)
-utm29 = CRS("+proj=utm +zone=29 +datum=WGS84")
+utm29 = CRS("+proj=utm +zone=29 +datum=WGS84 +ellps=WGS84")
 pts = spTransform(pts, utm29)
 
 
 ###################################################
-### code chunk number 38: jss816.Rnw:1102-1105
+### code chunk number 38: jss816.Rnw:1103-1106
 ###################################################
 wind.data = stConstruct(velocities, space = list(values = 1:ncol(velocities)), 
 	time = wind$time, SpatialObj = pts, interval = TRUE)
@@ -367,7 +368,7 @@ class(wind.data)
 
 
 ###################################################
-### code chunk number 39: jss816.Rnw:1108-1114
+### code chunk number 39: jss816.Rnw:1109-1115
 ###################################################
 library(maptools)
 m = map2SpatialLines(
@@ -378,20 +379,20 @@ m = spTransform(m, utm29)
 
 
 ###################################################
-### code chunk number 40: jss816.Rnw:1117-1119
+### code chunk number 40: jss816.Rnw:1118-1120
 ###################################################
 grd = SpatialPixels(SpatialPoints(makegrid(m, n = 300)),
 	proj4string = proj4string(m))
 
 
 ###################################################
-### code chunk number 41: jss816.Rnw:1122-1123
+### code chunk number 41: jss816.Rnw:1123-1124
 ###################################################
 wind.data = wind.data[, "1961-04"]
 
 
 ###################################################
-### code chunk number 42: jss816.Rnw:1127-1131
+### code chunk number 42: jss816.Rnw:1128-1132
 ###################################################
 n = 10
 library(xts)
@@ -400,7 +401,7 @@ pred.grd = STF(grd, tgrd)
 
 
 ###################################################
-### code chunk number 43: jss816.Rnw:1135-1139
+### code chunk number 43: jss816.Rnw:1136-1140
 ###################################################
 v = vgmST("separable", space = vgm(1, "Exp", 750000), time = vgm(1, "Exp", 1.5 * 3600 * 24),
          sill=0.6)
@@ -409,7 +410,7 @@ colnames(wind.ST@data) <- "sqrt_speed"
 
 
 ###################################################
-### code chunk number 44: jss816.Rnw:1145-1150 (eval = FALSE)
+### code chunk number 44: jss816.Rnw:1146-1151 (eval = FALSE)
 ###################################################
 ## layout = list(list("sp.lines", m, col='grey'),
 ## 	list("sp.points", pts, first=F, cex=.5))
@@ -419,7 +420,7 @@ colnames(wind.ST@data) <- "sqrt_speed"
 
 
 ###################################################
-### code chunk number 45: jss816.Rnw:1153-1160
+### code chunk number 45: jss816.Rnw:1154-1161
 ###################################################
 pdf("wind.pdf", height=4.5)
 layout = list(list("sp.lines", m, col='grey'),
@@ -431,7 +432,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 46: jss816.Rnw:1163-1174
+### code chunk number 46: jss816.Rnw:1164-1175
 ###################################################
 pdf("windts.pdf", height = 4)
 library(lattice)
@@ -447,7 +448,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 47: jss816.Rnw:1177-1182 (eval = FALSE)
+### code chunk number 47: jss816.Rnw:1178-1183 (eval = FALSE)
 ###################################################
 ## pdf("hov.pdf")
 ## scales=list(x=list(rot=45))
@@ -457,32 +458,32 @@ dev.off()
 
 
 ###################################################
-### code chunk number 48: jss816.Rnw:1188-1189 (eval = FALSE)
+### code chunk number 48: jss816.Rnw:1189-1190 (eval = FALSE)
 ###################################################
 ## eof.data = eof(wind.data)
 
 
 ###################################################
-### code chunk number 49: jss816.Rnw:1192-1193
+### code chunk number 49: jss816.Rnw:1193-1194
 ###################################################
 eof.int = eof(wind.ST)
 
 
 ###################################################
-### code chunk number 50: jss816.Rnw:1197-1198 (eval = FALSE)
+### code chunk number 50: jss816.Rnw:1198-1199 (eval = FALSE)
 ###################################################
 ## eof.xts = eof(wind.ST, "temporal")
 
 
 ###################################################
-### code chunk number 51: jss816.Rnw:1207-1209
+### code chunk number 51: jss816.Rnw:1208-1210
 ###################################################
 print(spplot(eof.int[1:4], col.regions=bpy.colors(),
 	par.strip.text = list(cex=.5), as.table = TRUE, sp.layout = layout))
 
 
 ###################################################
-### code chunk number 52: jss816.Rnw:1226-1235
+### code chunk number 52: jss816.Rnw:1227-1236
 ###################################################
 library(adehabitatLT)
 data("puechabonsp")
@@ -496,21 +497,21 @@ l2 = cutltraj(ltr, "foo(dt)", nextr = TRUE)
 
 
 ###################################################
-### code chunk number 53: jss816.Rnw:1239-1241 (eval = FALSE)
+### code chunk number 53: jss816.Rnw:1240-1242 (eval = FALSE)
 ###################################################
 ## sttdf = as(l2, "STTDF")
 ## stplot(sttdf, by="time*id")
 
 
 ###################################################
-### code chunk number 54: jss816.Rnw:1247-1249
+### code chunk number 54: jss816.Rnw:1248-1250
 ###################################################
 sttdf = as(l2, "STTDF")
 print(stplot(sttdf, by="time*id"))
 
 
 ###################################################
-### code chunk number 55: jss816.Rnw:1262-1266
+### code chunk number 55: jss816.Rnw:1263-1267
 ###################################################
 library(cshapes)
 cs = cshp()
@@ -519,7 +520,7 @@ row.names(cs) = paste(as.character(cs$CNTRY_NAME), 1:244)
 
 
 ###################################################
-### code chunk number 56: jss816.Rnw:1276-1281
+### code chunk number 56: jss816.Rnw:1277-1282
 ###################################################
 cs = cs[cs$COWSYEAR > -1,]
 begin = as.POSIXct(paste(cs$COWSYEAR, cs$COWSMONTH, cs$COWSDAY, sep="-"), 
@@ -529,41 +530,41 @@ end = as.POSIXct(paste(cs$COWEYEAR, cs$COWEMONTH,cs$COWEDAY, sep="-"),
 
 
 ###################################################
-### code chunk number 57: jss816.Rnw:1284-1285
+### code chunk number 57: jss816.Rnw:1285-1286
 ###################################################
 st = STIDF(geometry(cs), begin, as.data.frame(cs), end)
 
 
 ###################################################
-### code chunk number 58: jss816.Rnw:1289-1291
+### code chunk number 58: jss816.Rnw:1290-1292
 ###################################################
 pt = SpatialPoints(cbind(7, 52), CRS(proj4string(cs)))
 as.data.frame(st[pt,,1:5])
 
 
 ###################################################
-### code chunk number 59: jss816.Rnw:1315-1317 (eval = FALSE)
+### code chunk number 59: jss816.Rnw:1316-1318 (eval = FALSE)
 ###################################################
 ## library(spacetime)
 ## demo(CressieWikle)
 
 
 ###################################################
-### code chunk number 60: jss816.Rnw:1328-1330 (eval = FALSE)
+### code chunk number 60: jss816.Rnw:1329-1331 (eval = FALSE)
 ###################################################
 ## library(gstat)
 ## vignette("st")
 
 
 ###################################################
-### code chunk number 61: jss816.Rnw:1336-1338 (eval = FALSE)
+### code chunk number 61: jss816.Rnw:1337-1339 (eval = FALSE)
 ###################################################
 ## library(spacetime)
 ## vignette("stpg")
 
 
 ###################################################
-### code chunk number 62: jss816.Rnw:1350-1352 (eval = FALSE)
+### code chunk number 62: jss816.Rnw:1351-1353 (eval = FALSE)
 ###################################################
 ## library(spacetime)
 ## vignette("sto")
